import React, { useContext, useEffect } from "react";
import { Button, Card, Col, Row, Table, Typography } from "antd";
import { BreadcumbComponent } from "../../component/BreadcumbComponent";
import { LINKS } from "../../routes/app";
import { useStore } from "../../utils/useStore";
import { observer } from "mobx-react-lite";
import { FilterOutlined } from "@ant-design/icons";
import { format, parseISO } from "date-fns";
import { ModalLoaderContext } from "../../utils/modal";
import { useParams } from "react-router-dom";

const { Title, Text } = Typography;

export const ProductDetail = observer(() => {
  const store = useStore();
  const { id } = useParams();
  const modalLoader = useContext(ModalLoaderContext);

  const routeData = [
    {
      route: LINKS.HOME,
      name: "Home",
    },
    {
      route: LINKS.PRODUCT,
      name: <span style={{ fontWeight: "bold" }}>Product</span>,
    },
    {
      route: LINKS.PRODUCT_DETAIL,
      name: <span style={{ fontWeight: "bold" }}>Product Detail</span>,
    },
  ];

  useEffect(() => {
    (async () => {
      modalLoader.setLoading(true);
      await Promise.allSettled([
        //store.authentication.getProfile(),
        store.product.getDetail(id),
        store.product.getDetailProduct(id),
      ]);
      modalLoader.setLoading(false);
    })();
  }, []);

  //console.log(id)
  const columns = [
    {
      title: "Markup Price",
      dataIndex: "mark_up_price",
      key: "mark_up_price",
      width: "20%",
      render: (text) =>
        new Intl.NumberFormat("id-ID", {
          style: "currency",
          currency: "IDR",
        }).format(text),
    },
    {
      title: "Price",
      dataIndex: "price",
      key: "price",
      width: "50%",
      render: (text) =>
        new Intl.NumberFormat("id-ID", {
          style: "currency",
          currency: "IDR",
        }).format(text),
    },
    {
      title: "Transaction Date",
      dataIndex: "startDate",
      key: "startDate",
      render: (text, record) => {
        return (
          <Text>{format(parseISO(record.startDate), "dd MMMM yyyy")}</Text>
        );
      },
    },
  ];

  const styleSaldoTitle = store.ui.mediaQuery.isDesktop
    ? {
        display: "flex",
        justifyContent: "center",
      }
    : { fontSize: "0.75rem" };
  const styleSaldoContent = store.ui.mediaQuery.isDesktop
    ? {
        fontSize: "1.25rem",
        display: "flex",
        justifyContent: "center",
      }
    : null;

  return (
    <div className={["ppob-container"].join(" ")}>
      <BreadcumbComponent data={routeData} />
      <Card>
        <Title strong>Product Detail</Title>
        <Row style={{ marginBottom: 20 }}>
          <Col lg={12} xs={24}>
            <Row>
              <Col span={12}>
                <Text strong>Kode</Text>
              </Col>
              <Col span={12}>
                <Text>{store.product.dataDetailProduct.code}</Text>
              </Col>
              <Col span={12}>
                <Text strong>Nama Produk</Text>
              </Col>
              <Col span={10}>
                <Text>{store.product.dataDetailProduct.name}</Text>
              </Col>
              <Col span={12}>
                <Text strong>Harga Beli</Text>
              </Col>
              <Col span={12}>
                <Text>
                  {new Intl.NumberFormat("id-ID", {
                    style: "currency",
                    currency: "IDR",
                  }).format(store.product.dataDetailProduct.basePrice)}
                </Text>
              </Col>
              <Col span={12}>
                <Text strong>Harga Jual</Text>
              </Col>
              <Col span={12}>
                <Text>
                  {new Intl.NumberFormat("id-ID", {
                    style: "currency",
                    currency: "IDR",
                  }).format(store.product.dataDetailProduct.price)}
                </Text>
              </Col>
              <Col span={12}>
                <Text strong>Supplier</Text>
              </Col>
              <Col span={12}>
                <Text>{store.product.dataDetailProduct.supplier.name}</Text>
              </Col>
              <Col span={12}>
                <Text strong>Status</Text>
              </Col>
              <Col span={12}>
                <Text>{store.product.dataDetailProduct.status}</Text>
              </Col>
            </Row>
          </Col>
          {/* <Col lg={12} xs={24}>
            <Row justify={"center"}>
              <Col lg={24} xs={12}>
                <Title strong level={3} style={styleSaldoTitle}>Saldo</Title>
              </Col>
              <Col lg={24} xs={12}>
                <Text style={styleSaldoContent}>{store.authentication.profileData?.wallet}</Text>
              </Col>
            </Row>
          </Col> */}
        </Row>
        <Row>
          <Col span={24}>
            <div>
              <Title strong level={3}>
                Product Price History
              </Title>

              {/* <Button style={{marginBottom: '1rem'}} onClick={() => {
                console.log('clicked filter')
              }}>
                <FilterOutlined/>
                Filter
              </Button> */}
              <Table
                columns={columns}
                dataSource={store.product.dataDetail}
                bordered
              />
            </div>
          </Col>
        </Row>
        <div />
      </Card>
    </div>
  );
});
